@@ -8,11 +8,13 @@ from contextlib import contextmanager
 from functools import partial
 from importlib.metadata import version as pkgversion
 from pathlib import Path
-from typing import TYPE_CHECKING, Iterator
+from typing import TYPE_CHECKING
 
 from duty import duty, tools
 
 if TYPE_CHECKING:
+    from collections.abc import Iterator
+
     from duty.context import Context
 
 
@@ -86,8 +88,8 @@ def changelog(ctx: Context, bump: str = "") -> None:
     ctx.run(tools.git_changelog(bump=bump or None), title="Updating changelog")
 
 
-@duty(pre=["check_quality", "check_types", "check_docs", "check_dependencies", "check-api"])
-def check(ctx: Context) -> None:  # noqa: ARG001
+@duty(pre=["check-quality", "check-types", "check-docs", "check-api"])
+def check(ctx: Context) -> None:
     """Check it all!
 
     ```bash
@@ -308,9 +310,14 @@ def docs_deploy(ctx: Context) -> None:
     with material_insiders() as insiders:
         if not insiders:
             ctx.run(lambda: False, title="Not deploying docs without Material for MkDocs Insiders!")
-        origin = ctx.run("git config --get remote.origin.url", silent=True)
+        origin = ctx.run("git config --get remote.origin.url", silent=True, allow_overrides=False)
         if "pawamoy-insiders/griffe" in origin:
-            ctx.run("git remote add upstream git@github.com:mkdocstrings/griffe", silent=True, nofail=True)
+            ctx.run(
+                "git remote add upstream git@github.com:mkdocstrings/griffe",
+                silent=True,
+                nofail=True,
+                allow_overrides=False,
+            )
             ctx.run(
                 tools.mkdocs.gh_deploy(remote_name="upstream", force=True),
                 title="Deploying documentation",
@@ -495,7 +502,7 @@ def fuzz(
     from pysource_codegen import generate
     from pysource_minimize import minimize
 
-    from griffe.agents.visitor import visit
+    from griffe import visit
 
     warnings.simplefilter("ignore", SyntaxWarning)
 
