@@ -7,29 +7,25 @@ import ast
 from inspect import Parameter as SignatureParameter
 from inspect import Signature, cleandoc, getsourcelines
 from inspect import signature as getsignature
-from typing import TYPE_CHECKING, Any, Sequence
+from typing import TYPE_CHECKING, Any
 
 from _griffe.agents.nodes.runtime import ObjectNode
 from _griffe.collections import LinesCollection, ModulesCollection
-from _griffe.enumerations import ObjectKind, ParameterKind
+from _griffe.enumerations import Kind, ParameterKind
 from _griffe.expressions import safe_get_annotation
 from _griffe.extensions.base import Extensions, load_extensions
 from _griffe.importer import dynamic_import
-
-# YORE: Bump 1: Replace `_logger` with `logger` within file.
-# YORE: Bump 1: Replace `get_logger` with `logger` within line.
-from _griffe.logger import get_logger
+from _griffe.logger import logger
 from _griffe.models import Alias, Attribute, Class, Docstring, Function, Module, Parameter, Parameters
 
 if TYPE_CHECKING:
+    from collections.abc import Sequence
     from pathlib import Path
 
     from _griffe.enumerations import Parser
     from _griffe.expressions import Expr
 
 
-# YORE: Bump 1: Remove line.
-_logger = get_logger("griffe.agents.inspector")
 _empty = Signature.empty
 
 
@@ -132,7 +128,7 @@ class Inspector:
         self.filepath: Path | None = filepath
         """The module file path."""
 
-        self.extensions: Extensions = extensions.attach_inspector(self)
+        self.extensions: Extensions = extensions
         """The extensions to use when inspecting."""
 
         self.parent: Module | None = parent
@@ -239,11 +235,7 @@ class Inspector:
         Parameters:
             node: The node to inspect.
         """
-        for before_inspector in self.extensions.before_inspection:
-            before_inspector.inspect(node)
         getattr(self, f"inspect_{node.kind}", self.generic_inspect)(node)
-        for after_inspector in self.extensions.after_inspection:
-            after_inspector.inspect(node)
 
     def generic_inspect(self, node: ObjectNode) -> None:
         """Extend the base generic inspection with extensions.
@@ -251,9 +243,6 @@ class Inspector:
         Parameters:
             node: The node to inspect.
         """
-        for before_inspector in self.extensions.before_children_inspection:
-            before_inspector.inspect(node)
-
         for child in node.children:
             if target_path := child.alias_target_path:
                 # If the child is an actual submodule of the current module,
@@ -264,7 +253,7 @@ class Inspector:
                 # so we skip it here (no member, no alias, just skip it).
                 if child.is_module and target_path == f"{self.current.path}.{child.name}":
                     if not hasattr(child.obj, "__file__"):
-                        _logger.debug(f"Module {target_path} is not discoverable on disk, inspecting right now")
+                        logger.debug("Module %s is not discoverable on disk, inspecting right now", target_path)
                         inspector = Inspector(
                             child.name,
                             filepath=None,
@@ -275,28 +264,24 @@ class Inspector:
                             lines_collection=self.lines_collection,
                             modules_collection=self.modules_collection,
                         )
-                        try:
-                            inspector.inspect_module(child)
-                        finally:
-                            self.extensions.attach_inspector(self)
+                        inspector.inspect_module(child)
                         self.current.set_member(child.name, inspector.current.module)
                 # Otherwise, alias the object.
                 else:
-                    self.current.set_member(child.name, Alias(child.name, target_path))
+                    alias = Alias(child.name, target_path)
+                    self.current.set_member(child.name, alias)
+                    self.extensions.call("on_alias", alias=alias, node=node, agent=self)
             else:
                 self.inspect(child)
 
-        for after_inspector in self.extensions.after_children_inspection:
-            after_inspector.inspect(node)
-
     def inspect_module(self, node: ObjectNode) -> None:
         """Inspect a module.
 
         Parameters:
             node: The node to inspect.
         """
-        self.extensions.call("on_node", node=node)
-        self.extensions.call("on_module_node", node=node)
+        self.extensions.call("on_node", node=node, agent=self)
+        self.extensions.call("on_module_node", node=node, agent=self)
         self.current = module = Module(
             name=self.module_name,
             filepath=self.filepath,
@@ -305,11 +290,11 @@ class Inspector:
             lines_collection=self.lines_collection,
             modules_collection=self.modules_collection,
         )
-        self.extensions.call("on_instance", node=node, obj=module)
-        self.extensions.call("on_module_instance", node=node, mod=module)
+        self.extensions.call("on_instance", node=node, obj=module, agent=self)
+        self.extensions.call("on_module_instance", node=node, mod=module, agent=self)
         self.generic_inspect(node)
-        self.extensions.call("on_members", node=node, obj=module)
-        self.extensions.call("on_module_members", node=node, mod=module)
+        self.extensions.call("on_members", node=node, obj=module, agent=self)
+        self.extensions.call("on_module_members", node=node, mod=module, agent=self)
 
     def inspect_class(self, node: ObjectNode) -> None:
         """Inspect a class.
@@ -317,8 +302,8 @@ class Inspector:
         Parameters:
             node: The node to inspect.
         """
-        self.extensions.call("on_node", node=node)
-        self.extensions.call("on_class_node", node=node)
+        self.extensions.call("on_node", node=node, agent=self)
+        self.extensions.call("on_class_node", node=node, agent=self)
 
         bases = []
         for base in node.obj.__bases__:
@@ -336,11 +321,11 @@ class Inspector:
         )
         self.current.set_member(node.name, class_)
         self.current = class_
-        self.extensions.call("on_instance", node=node, obj=class_)
-        self.extensions.call("on_class_instance", node=node, cls=class_)
+        self.extensions.call("on_instance", node=node, obj=class_, agent=self)
+        self.extensions.call("on_class_instance", node=node, cls=class_, agent=self)
         self.generic_inspect(node)
-        self.extensions.call("on_members", node=node, obj=class_)
-        self.extensions.call("on_class_members", node=node, cls=class_)
+        self.extensions.call("on_members", node=node, obj=class_, agent=self)
+        self.extensions.call("on_class_members", node=node, cls=class_, agent=self)
         self.current = self.current.parent  # type: ignore[assignment]
 
     def inspect_staticmethod(self, node: ObjectNode) -> None:
@@ -430,8 +415,8 @@ class Inspector:
             node: The node to inspect.
             labels: Labels to add to the data object.
         """
-        self.extensions.call("on_node", node=node)
-        self.extensions.call("on_function_node", node=node)
+        self.extensions.call("on_node", node=node, agent=self)
+        self.extensions.call("on_function_node", node=node, agent=self)
 
         try:
             signature = getsignature(node.obj)
@@ -475,11 +460,11 @@ class Inspector:
             )
         obj.labels |= labels
         self.current.set_member(node.name, obj)
-        self.extensions.call("on_instance", node=node, obj=obj)
+        self.extensions.call("on_instance", node=node, obj=obj, agent=self)
         if obj.is_attribute:
-            self.extensions.call("on_attribute_instance", node=node, attr=obj)
+            self.extensions.call("on_attribute_instance", node=node, attr=obj, agent=self)
         else:
-            self.extensions.call("on_function_instance", node=node, func=obj)
+            self.extensions.call("on_function_instance", node=node, func=obj, agent=self)
 
     def inspect_attribute(self, node: ObjectNode) -> None:
         """Inspect an attribute.
@@ -494,23 +479,23 @@ class Inspector:
 
         Parameters:
             node: The node to inspect.
-            annotation: A potentiel annotation.
+            annotation: A potential annotation.
         """
-        self.extensions.call("on_node", node=node)
-        self.extensions.call("on_attribute_node", node=node)
+        self.extensions.call("on_node", node=node, agent=self)
+        self.extensions.call("on_attribute_node", node=node, agent=self)
 
-        # TODO: to improve
+        # TODO: To improve.
         parent = self.current
         labels: set[str] = set()
 
-        if parent.kind is ObjectKind.MODULE:
+        if parent.kind is Kind.MODULE:
             labels.add("module")
-        elif parent.kind is ObjectKind.CLASS:
+        elif parent.kind is Kind.CLASS:
             labels.add("class")
-        elif parent.kind is ObjectKind.FUNCTION:
+        elif parent.kind is Kind.FUNCTION:
             if parent.name != "__init__":
                 return
-            parent = parent.parent
+            parent = parent.parent  # type: ignore[assignment]
             labels.add("instance")
 
         try:
@@ -533,8 +518,8 @@ class Inspector:
 
         if node.name == "__all__":
             parent.exports = set(node.obj)
-        self.extensions.call("on_instance", node=node, obj=attribute)
-        self.extensions.call("on_attribute_instance", node=node, attr=attribute)
+        self.extensions.call("on_instance", node=node, obj=attribute, agent=self)
+        self.extensions.call("on_attribute_instance", node=node, attr=attribute, agent=self)
 
 
 _kind_map = {
