@@ -154,7 +154,7 @@ class Visitor:
         self.code: str = code
         """The module source code."""
 
-        self.extensions: Extensions = extensions.attach_visitor(self)
+        self.extensions: Extensions = extensions
         """The extensions to use when visiting the AST."""
 
         self.parent: Module | None = parent
@@ -210,11 +210,7 @@ class Visitor:
         Parameters:
             node: The node to visit.
         """
-        for before_visitor in self.extensions.before_visit:
-            before_visitor.visit(node)
         getattr(self, f"visit_{ast_kind(node)}", self.generic_visit)(node)
-        for after_visitor in self.extensions.after_visit:
-            after_visitor.visit(node)
 
     def generic_visit(self, node: ast.AST) -> None:
         """Extend the base generic visit with extensions.
@@ -222,12 +218,8 @@ class Visitor:
         Parameters:
             node: The node to visit.
         """
-        for before_visitor in self.extensions.before_children_visit:
-            before_visitor.visit(node)
         for child in ast_children(node):
             self.visit(child)
-        for after_visitor in self.extensions.after_children_visit:
-            after_visitor.visit(node)
 
     def visit_module(self, node: ast.Module) -> None:
         """Visit a module node.
@@ -235,8 +227,8 @@ class Visitor:
         Parameters:
             node: The node to visit.
         """
-        self.extensions.call("on_node", node=node)
-        self.extensions.call("on_module_node", node=node)
+        self.extensions.call("on_node", node=node, agent=self)
+        self.extensions.call("on_module_node", node=node, agent=self)
         self.current = module = Module(
             name=self.module_name,
             filepath=self.filepath,
@@ -245,11 +237,11 @@ class Visitor:
             lines_collection=self.lines_collection,
             modules_collection=self.modules_collection,
         )
-        self.extensions.call("on_instance", node=node, obj=module)
-        self.extensions.call("on_module_instance", node=node, mod=module)
+        self.extensions.call("on_instance", node=node, obj=module, agent=self)
+        self.extensions.call("on_module_instance", node=node, mod=module, agent=self)
         self.generic_visit(node)
-        self.extensions.call("on_members", node=node, obj=module)
-        self.extensions.call("on_module_members", node=node, mod=module)
+        self.extensions.call("on_members", node=node, obj=module, agent=self)
+        self.extensions.call("on_module_members", node=node, mod=module, agent=self)
 
     def visit_classdef(self, node: ast.ClassDef) -> None:
         """Visit a class definition node.
@@ -257,29 +249,26 @@ class Visitor:
         Parameters:
             node: The node to visit.
         """
-        self.extensions.call("on_node", node=node)
-        self.extensions.call("on_class_node", node=node)
+        self.extensions.call("on_node", node=node, agent=self)
+        self.extensions.call("on_class_node", node=node, agent=self)
 
         # handle decorators
-        decorators = []
+        decorators: list[Decorator] = []
         if node.decorator_list:
             lineno = node.decorator_list[0].lineno
-            for decorator_node in node.decorator_list:
-                decorators.append(
-                    Decorator(
-                        safe_get_expression(decorator_node, parent=self.current, parse_strings=False),  # type: ignore[arg-type]
-                        lineno=decorator_node.lineno,
-                        endlineno=decorator_node.end_lineno,
-                    ),
+            decorators.extend(
+                Decorator(
+                    safe_get_expression(decorator_node, parent=self.current, parse_strings=False),  # type: ignore[arg-type]
+                    lineno=decorator_node.lineno,
+                    endlineno=decorator_node.end_lineno,
                 )
+                for decorator_node in node.decorator_list
+            )
         else:
             lineno = node.lineno
 
         # handle base classes
-        bases = []
-        if node.bases:
-            for base in node.bases:
-                bases.append(safe_get_base_class(base, parent=self.current))
+        bases = [safe_get_base_class(base, parent=self.current) for base in node.bases]
 
         class_ = Class(
             name=node.name,
@@ -293,11 +282,11 @@ class Visitor:
         class_.labels |= self.decorators_to_labels(decorators)
         self.current.set_member(node.name, class_)
         self.current = class_
-        self.extensions.call("on_instance", node=node, obj=class_)
-        self.extensions.call("on_class_instance", node=node, cls=class_)
+        self.extensions.call("on_instance", node=node, obj=class_, agent=self)
+        self.extensions.call("on_class_instance", node=node, cls=class_, agent=self)
         self.generic_visit(node)
-        self.extensions.call("on_members", node=node, obj=class_)
-        self.extensions.call("on_class_members", node=node, cls=class_)
+        self.extensions.call("on_members", node=node, obj=class_, agent=self)
+        self.extensions.call("on_class_members", node=node, cls=class_, agent=self)
         self.current = self.current.parent  # type: ignore[assignment]
 
     def decorators_to_labels(self, decorators: list[Decorator]) -> set[str]:
@@ -349,8 +338,8 @@ class Visitor:
             node: The node to visit.
             labels: Labels to add to the data object.
         """
-        self.extensions.call("on_node", node=node)
-        self.extensions.call("on_function_node", node=node)
+        self.extensions.call("on_node", node=node, agent=self)
+        self.extensions.call("on_function_node", node=node, agent=self)
 
         labels = labels or set()
 
@@ -387,8 +376,8 @@ class Visitor:
             )
             attribute.labels |= labels
             self.current.set_member(node.name, attribute)
-            self.extensions.call("on_instance", node=node, obj=attribute)
-            self.extensions.call("on_attribute_instance", node=node, attr=attribute)
+            self.extensions.call("on_instance", node=node, obj=attribute, agent=self)
+            self.extensions.call("on_attribute_instance", node=node, attr=attribute, agent=self)
             return
 
         # handle parameters
@@ -423,7 +412,7 @@ class Visitor:
         if overload:
             self.current.overloads[function.name].append(function)
         elif property_function:
-            base_property: Function = self.current.members[node.name]  # type: ignore[assignment]
+            base_property: Attribute = self.current.members[node.name]  # type: ignore[assignment]
             if property_function == "setter":
                 base_property.setter = function
                 base_property.labels.add("writable")
@@ -438,8 +427,8 @@ class Visitor:
 
         function.labels |= labels
 
-        self.extensions.call("on_instance", node=node, obj=function)
-        self.extensions.call("on_function_instance", node=node, func=function)
+        self.extensions.call("on_instance", node=node, obj=function, agent=self)
+        self.extensions.call("on_function_instance", node=node, func=function, agent=self)
         if self.current.kind is Kind.CLASS and function.name == "__init__":
             self.current = function  # type: ignore[assignment]  # temporary assign a function
             self.generic_visit(node)
@@ -471,16 +460,15 @@ class Visitor:
             alias_path = name.name if name.asname else name.name.split(".", 1)[0]
             alias_name = name.asname or alias_path.split(".", 1)[0]
             self.current.imports[alias_name] = alias_path
-            self.current.set_member(
+            alias = Alias(
                 alias_name,
-                Alias(
-                    alias_name,
-                    alias_path,
-                    lineno=node.lineno,
-                    endlineno=node.end_lineno,
-                    runtime=not self.type_guarded,
-                ),
+                alias_path,
+                lineno=node.lineno,
+                endlineno=node.end_lineno,
+                runtime=not self.type_guarded,
             )
+            self.current.set_member(alias_name, alias)
+            self.extensions.call("on_alias", alias=alias, node=node, agent=self)
 
     def visit_importfrom(self, node: ast.ImportFrom) -> None:
         """Visit an "import from" node.
@@ -507,16 +495,15 @@ class Visitor:
             # `from package.current_module import Thing as Thing` or
             # `from . import thing as thing`).
             if alias_path != f"{self.current.path}.{alias_name}":
-                self.current.set_member(
+                alias = Alias(
                     alias_name,
-                    Alias(
-                        alias_name,
-                        alias_path,
-                        lineno=node.lineno,
-                        endlineno=node.end_lineno,
-                        runtime=not self.type_guarded,
-                    ),
+                    alias_path,
+                    lineno=node.lineno,
+                    endlineno=node.end_lineno,
+                    runtime=not self.type_guarded,
                 )
+                self.current.set_member(alias_name, alias)
+                self.extensions.call("on_alias", alias=alias, node=node, agent=self)
 
     def handle_attribute(
         self,
@@ -529,8 +516,8 @@ class Visitor:
             node: The node to visit.
             annotation: A potential annotation.
         """
-        self.extensions.call("on_node", node=node)
-        self.extensions.call("on_attribute_node", node=node)
+        self.extensions.call("on_node", node=node, agent=self)
+        self.extensions.call("on_attribute_node", node=node, agent=self)
         parent = self.current
         labels = set()
 
@@ -618,8 +605,8 @@ class Visitor:
                         name if isinstance(name, str) else ExprName(name.name, parent=name.parent)
                         for name in safe_get__all__(node, self.current)  # type: ignore[arg-type]
                     ]
-            self.extensions.call("on_instance", node=node, obj=attribute)
-            self.extensions.call("on_attribute_instance", node=node, attr=attribute)
+            self.extensions.call("on_instance", node=node, obj=attribute, agent=self)
+            self.extensions.call("on_attribute_instance", node=node, attr=attribute, agent=self)
 
     def visit_assign(self, node: ast.Assign) -> None:
         """Visit an assignment node.
