@@ -19,7 +19,7 @@ import os
 import sys
 from datetime import datetime, timezone
 from pathlib import Path
-from typing import IO, TYPE_CHECKING, Any, Callable, Sequence
+from typing import IO, TYPE_CHECKING, Any, Callable
 
 import colorama
 
@@ -31,24 +31,20 @@ from _griffe.exceptions import ExtensionError, GitError
 from _griffe.extensions.base import load_extensions
 from _griffe.git import get_latest_tag, get_repo_root
 from _griffe.loader import GriffeLoader, load, load_git
-
-# YORE: Bump 1: Replace `_logger` with `logger` within file.
-# YORE: Bump 1: Replace `get_logger` with `logger` within line.
-from _griffe.logger import get_logger
+from _griffe.logger import logger
 
 if TYPE_CHECKING:
-    from _griffe.extensions.base import Extensions, ExtensionType
+    from collections.abc import Sequence
+
+    from _griffe.extensions.base import Extension, Extensions
 
 
 DEFAULT_LOG_LEVEL = os.getenv("GRIFFE_LOG_LEVEL", "INFO").upper()
 """The default log level for the CLI.
 
-This can be overriden by the `GRIFFE_LOG_LEVEL` environment variable.
+This can be overridden by the `GRIFFE_LOG_LEVEL` environment variable.
 """
 
-# YORE: Bump 1: Remove line.
-_logger = get_logger("griffe.cli")
-
 
 class _DebugInfo(argparse.Action):
     def __init__(self, nargs: int | str | None = 0, **kwargs: Any) -> None:
@@ -61,7 +57,7 @@ class _DebugInfo(argparse.Action):
 
 def _print_data(data: str, output_file: str | IO | None) -> None:
     if isinstance(output_file, str):
-        with open(output_file, "w") as fd:
+        with open(output_file, "w") as fd:  # noqa: PTH123
             print(data, file=fd)
     else:
         if output_file is None:
@@ -98,25 +94,25 @@ def _load_packages(
     # Load each package.
     for package in packages:
         if not package:
-            _logger.debug("Empty package name, continuing")
+            logger.debug("Empty package name, continuing")
             continue
-        _logger.info(f"Loading package {package}")
+        logger.info("Loading package %s", package)
         try:
             loader.load(package, try_relative_path=True, find_stubs_package=find_stubs_package)
         except ModuleNotFoundError as error:
-            _logger.error(f"Could not find package {package}: {error}")  # noqa: TRY400
-        except ImportError as error:
-            _logger.exception(f"Tried but could not import package {package}: {error}")  # noqa: TRY401
-    _logger.info("Finished loading packages")
+            logger.error("Could not find package %s: %s", package, error)  # noqa: TRY400
+        except ImportError:
+            logger.exception("Tried but could not import package %s", package)
+    logger.info("Finished loading packages")
 
     # Resolve aliases.
     if resolve_aliases:
-        _logger.info("Starting alias resolution")
+        logger.info("Starting alias resolution")
         unresolved, iterations = loader.resolve_aliases(implicit=resolve_implicit, external=resolve_external)
         if unresolved:
-            _logger.info(f"{len(unresolved)} aliases were still unresolved after {iterations} iterations")
+            logger.info("%s aliases were still unresolved after %s iterations", len(unresolved), iterations)
         else:
-            _logger.info(f"All aliases were resolved after {iterations} iterations")
+            logger.info("All aliases were resolved after %s iterations", iterations)
     return loader
 
 
@@ -267,8 +263,8 @@ def get_parser() -> argparse.ArgumentParser:
         "-I",
         "--resolve-implicit",
         action="store_true",
-        help="Whether to resolve implicitely exported aliases as well. "
-        "Aliases are explicitely exported when defined in `__all__`.",
+        help="Whether to resolve implicitly exported aliases as well. "
+        "Aliases are explicitly exported when defined in `__all__`.",
     )
     dump_options.add_argument(
         "-U",
@@ -324,7 +320,7 @@ def get_parser() -> argparse.ArgumentParser:
         help="Force disable colors in the output.",
     )
     check_options.add_argument("-v", "--verbose", action="store_true", help="Verbose output.")
-    formats = ("oneline", "verbose")
+    formats = [fmt.value for fmt in ExplanationStyle]
     check_options.add_argument("-f", "--format", dest="style", choices=formats, default=None, help="Output format.")
     add_common_options(check_parser)
 
@@ -338,7 +334,7 @@ def dump(
     full: bool = False,
     docstring_parser: Parser | None = None,
     docstring_options: dict[str, Any] | None = None,
-    extensions: Sequence[str | dict[str, Any] | ExtensionType | type[ExtensionType]] | None = None,
+    extensions: Sequence[str | dict[str, Any] | Extension | type[Extension]] | None = None,
     resolve_aliases: bool = False,
     resolve_implicit: bool = False,
     resolve_external: bool | None = None,
@@ -385,8 +381,8 @@ def dump(
 
     try:
         loaded_extensions = load_extensions(*(extensions or ()))
-    except ExtensionError as error:
-        _logger.exception(str(error))  # noqa: TRY401
+    except ExtensionError:
+        logger.exception("Could not load extensions")
         return 1
 
     # Load packages.
@@ -410,17 +406,17 @@ def dump(
     started = datetime.now(tz=timezone.utc)
     if per_package_output:
         for package_name, data in data_packages.items():
-            serialized = data.as_json(indent=2, full=full)
+            serialized = data.as_json(indent=2, full=full, sort_keys=True)
             _print_data(serialized, output.format(package=package_name))  # type: ignore[union-attr]
     else:
-        serialized = json.dumps(data_packages, cls=JSONEncoder, indent=2, full=full)
+        serialized = json.dumps(data_packages, cls=JSONEncoder, indent=2, full=full, sort_keys=True)
         _print_data(serialized, output)
     elapsed = datetime.now(tz=timezone.utc) - started
 
     if stats:
         loader_stats = loader.stats()
         loader_stats.time_spent_serializing = elapsed.microseconds
-        _logger.info(loader_stats.as_text())
+        logger.info(loader_stats.as_text())
 
     return 0 if len(data_packages) == len(packages) else 1
 
@@ -431,7 +427,7 @@ def check(
     against_path: str | Path | None = None,
     *,
     base_ref: str | None = None,
-    extensions: Sequence[str | dict[str, Any] | ExtensionType | type[ExtensionType]] | None = None,
+    extensions: Sequence[str | dict[str, Any] | Extension | type[Extension]] | None = None,
     search_paths: Sequence[str | Path] | None = None,
     append_sys_path: bool = False,
     find_stubs_package: bool = False,
@@ -473,8 +469,8 @@ def check(
 
     try:
         loaded_extensions = load_extensions(*(extensions or ()))
-    except ExtensionError as error:
-        _logger.exception(str(error))  # noqa: TRY401
+    except ExtensionError:
+        logger.exception("Could not load extensions")
         return 1
 
     # Load old and new version of the package.
