@@ -3,35 +3,36 @@
 from __future__ import annotations
 
 import sys
-import warnings
 from contextlib import suppress
 from datetime import datetime, timezone
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, ClassVar, Sequence, cast
+from typing import TYPE_CHECKING, Any, ClassVar, cast
 
 from _griffe.agents.inspector import inspect
 from _griffe.agents.visitor import visit
 from _griffe.collections import LinesCollection, ModulesCollection
 from _griffe.enumerations import Kind
-from _griffe.exceptions import AliasResolutionError, CyclicAliasError, LoadingError, UnimportableModuleError
+from _griffe.exceptions import (
+    AliasResolutionError,
+    CyclicAliasError,
+    LoadingError,
+    UnimportableModuleError,
+)
 from _griffe.expressions import ExprName
 from _griffe.extensions.base import Extensions, load_extensions
 from _griffe.finder import ModuleFinder, NamespacePackage, Package
 from _griffe.git import tmp_worktree
 from _griffe.importer import dynamic_import
-
-# YORE: Bump 1: Replace `_logger` with `logger` within file.
-# YORE: Bump 1: Replace `get_logger` with `logger` within line.
-from _griffe.logger import get_logger
+from _griffe.logger import logger
 from _griffe.merger import merge_stubs
 from _griffe.models import Alias, Module, Object
 from _griffe.stats import Stats
 
 if TYPE_CHECKING:
+    from collections.abc import Sequence
+
     from _griffe.enumerations import Parser
 
-# YORE: Bump 1: Remove line.
-_logger = get_logger("griffe.loader")
 _builtin_modules: set[str] = set(sys.builtin_module_names)
 
 
@@ -92,31 +93,6 @@ class GriffeLoader:
             "time_spent_inspecting": 0,
         }
 
-    # YORE: Bump 1: Remove block.
-    def load_module(
-        self,
-        module: str | Path,
-        *,
-        submodules: bool = True,
-        try_relative_path: bool = True,
-        find_stubs_package: bool = False,
-    ) -> Object:
-        """Renamed `load`. Load an object as a Griffe object, given its dotted path.
-
-        This method was renamed [`load`][griffe.GriffeLoader.load].
-        """
-        warnings.warn(
-            "The `load_module` method was renamed `load`, and is deprecated.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        return self.load(  # type: ignore[return-value]
-            module,
-            submodules=submodules,
-            try_relative_path=try_relative_path,
-            find_stubs_package=find_stubs_package,
-        )
-
     def load(
         self,
         objspec: str | Path | None = None,
@@ -125,8 +101,6 @@ class GriffeLoader:
         submodules: bool = True,
         try_relative_path: bool = True,
         find_stubs_package: bool = False,
-        # YORE: Bump 1: Remove line.
-        module: str | Path | None = None,
     ) -> Object | Alias:
         """Load an object as a Griffe object, given its Python or file path.
 
@@ -147,7 +121,6 @@ class GriffeLoader:
             find_stubs_package: Whether to search for stubs-only package.
                 If both the package and its stubs are found, they'll be merged together.
                 If only the stubs are found, they'll be used as the package itself.
-            module: Deprecated. Use `objspec` positional-only parameter instead.
 
         Raises:
             LoadingError: When loading a module failed for various reasons.
@@ -156,24 +129,13 @@ class GriffeLoader:
         Returns:
             A Griffe object.
         """
-        # YORE: Bump 1: Remove block.
-        if objspec is None and module is None:
-            raise TypeError("load() missing 1 required positional argument: 'objspec'")
-        if objspec is None:
-            objspec = module
-            warnings.warn(
-                "Parameter 'module' was renamed 'objspec' and made positional-only.",
-                DeprecationWarning,
-                stacklevel=2,
-            )
-
         obj_path: str
         package = None
         top_module = None
 
         # We always start by searching paths on the disk,
         # even if inspection is forced.
-        _logger.debug(f"Searching path(s) for {objspec}")
+        logger.debug("Searching path(s) for %s", objspec)
         try:
             obj_path, package = self.finder.find_spec(
                 objspec,  # type: ignore[arg-type]
@@ -183,14 +145,14 @@ class GriffeLoader:
         except ModuleNotFoundError:
             # If we couldn't find paths on disk and inspection is disabled,
             # re-raise ModuleNotFoundError.
-            _logger.debug(f"Could not find path for {objspec} on disk")
+            logger.debug("Could not find path for %s on disk", objspec)
             if not (self.allow_inspection or self.force_inspection):
                 raise
 
             # Otherwise we try to dynamically import the top-level module.
             obj_path = str(objspec)
             top_module_name = obj_path.split(".", 1)[0]
-            _logger.debug(f"Trying to dynamically import {top_module_name}")
+            logger.debug("Trying to dynamically import %s", top_module_name)
             top_module_object = dynamic_import(top_module_name, self.finder.search_paths)
 
             try:
@@ -200,15 +162,13 @@ class GriffeLoader:
             except (AttributeError, ValueError):
                 # If the top-level module has no `__path__`, we inspect it as-is,
                 # and do not try to recurse into submodules (there shouldn't be any in builtin/compiled modules).
-                _logger.debug(f"Module {top_module_name} has no paths set (built-in module?). Inspecting it as-is.")
+                logger.debug("Module %s has no paths set (built-in module?). Inspecting it as-is.", top_module_name)
                 top_module = self._inspect_module(top_module_name)
                 self.modules_collection.set_member(top_module.path, top_module)
-                obj = self.modules_collection.get_member(obj_path)
-                self.extensions.call("on_package_loaded", pkg=obj)
-                return obj
+                return self._post_load(top_module, obj_path)
 
             # We found paths, and use them to build our intermediate Package or NamespacePackage struct.
-            _logger.debug(f"Module {top_module_name} has paths set: {top_module_path}")
+            logger.debug("Module %s has paths set: %s", top_module_name, top_module_path)
             top_module_path = [Path(path) for path in top_module_path]
             if len(top_module_path) > 1:
                 package = NamespacePackage(top_module_name, top_module_path)
@@ -216,16 +176,40 @@ class GriffeLoader:
                 package = Package(top_module_name, top_module_path[0])
 
         # We have an intermediate package, and an object path: we're ready to load.
-        _logger.debug(f"Found {objspec}: loading")
+        logger.debug("Found %s: loading", objspec)
         try:
             top_module = self._load_package(package, submodules=submodules)
-        except LoadingError as error:
-            _logger.exception(str(error))  # noqa: TRY401
+        except LoadingError:
+            logger.exception("Could not load package %s", package)
             raise
 
+        return self._post_load(top_module, obj_path)
+
+    def _post_load(self, module: Module, obj_path: str) -> Object | Alias:
+        # Pre-emptively expand exports (`__all__` values),
+        # as well as wildcard imports (without ever loading additional packages).
+        # This is a best-effort to return the most correct API data
+        # before firing the `on_package_loaded` event,
+        # because extensions registering hooks for this event
+        # might trigger computation of inherited members,
+        # which are cached, and could be cached too early
+        # (aliases to base class still being unresolvable,
+        # preventing to fetch some inherited members).
+        #
+        # Another solution to this "too-early-computation-of-inherited-members"
+        # issue would be to stop caching resolved bases and inherited members,
+        # but we would have to measure the performance impact of this change,
+        # as each use of `obj["name"]` would compute resolved bases, MRO
+        # and inherited members again.
+        #
+        # Packages that wildcard imports from external, non-loaded packages
+        # will still have incomplete data, requiring subsequent calls to
+        # `load()` and/or `resolve_aliases()`.
+        self.expand_exports(module)
+        self.expand_wildcards(module, external=False)
         # Package is loaded, we now retrieve the initially requested object and return it.
         obj = self.modules_collection.get_member(obj_path)
-        self.extensions.call("on_package_loaded", pkg=top_module)
+        self.extensions.call("on_package_loaded", pkg=module, loader=self)
         return obj
 
     def resolve_aliases(
@@ -238,7 +222,7 @@ class GriffeLoader:
         """Resolve aliases.
 
         Parameters:
-            implicit: When false, only try to resolve an alias if it is explicitely exported.
+            implicit: When false, only try to resolve an alias if it is explicitly exported.
             external: When false, don't try to load unspecified modules to resolve aliases.
             max_iterations: Maximum number of iterations on the loader modules collection.
 
@@ -252,11 +236,11 @@ class GriffeLoader:
         iteration = 0
         collection = self.modules_collection.members
 
-        # We must first expand exports (`__all__` values),
-        # then expand wildcard imports (`from ... import *`),
-        # and then only we can start resolving aliases.
-        for exports_module in list(collection.values()):
-            self.expand_exports(exports_module)
+        # Before resolving aliases, we try to expand wildcard imports again
+        # (this was already done in `_post_load()`),
+        # this time with the user-configured `external` setting,
+        # and with potentially more packages loaded in the collection,
+        # allowing to resolve more aliases.
         for wildcards_module in list(collection.values()):
             self.expand_wildcards(wildcards_module, external=external)
 
@@ -276,8 +260,9 @@ class GriffeLoader:
                 )
                 resolved |= next_resolved
                 unresolved |= next_unresolved
-            _logger.debug(
-                f"Iteration {iteration} finished, {len(resolved)} aliases resolved, still {len(unresolved)} to go",
+            logger.debug(
+                "Iteration %s finished, {len(resolved)} aliases resolved, still {len(unresolved)} to go",
+                iteration,
             )
         return unresolved, iteration
 
@@ -292,6 +277,7 @@ class GriffeLoader:
         seen.add(module.path)
         if module.exports is None:
             return
+
         expanded = set()
         for export in module.exports:
             # It's a name: we resolve it, get the module it comes from,
@@ -301,19 +287,24 @@ class GriffeLoader:
                 try:
                     next_module = self.modules_collection.get_member(module_path)
                 except KeyError:
-                    _logger.debug(f"Cannot expand '{export.canonical_path}', try pre-loading corresponding package")
+                    logger.debug("Cannot expand '%s', try pre-loading corresponding package", export.canonical_path)
                     continue
                 if next_module.path not in seen:
                     self.expand_exports(next_module, seen)
                     try:
                         expanded |= next_module.exports
                     except TypeError:
-                        _logger.warning(f"Unsupported item in {module.path}.__all__: {export} (use strings only)")
+                        logger.warning("Unsupported item in %s.__all__: %s (use strings only)", module.path, export)
             # It's a string, simply add it to the current exports.
             else:
                 expanded.add(export)
         module.exports = expanded
 
+        # Make sure to expand exports in all modules.
+        for submodule in module.modules.values():
+            if not submodule.is_alias and submodule.path not in seen:
+                self.expand_exports(submodule, seen)
+
     def expand_wildcards(
         self,
         obj: Object,
@@ -348,16 +339,18 @@ class GriffeLoader:
                     try:
                         self.load(package, try_relative_path=False)
                     except (ImportError, LoadingError) as error:
-                        _logger.debug(f"Could not expand wildcard import {member.name} in {obj.path}: {error}")
+                        logger.debug("Could not expand wildcard import %s in %s: %s", member.name, obj.path, error)
                         continue
 
                 # Try getting the module from which every public object is imported.
                 try:
                     target = self.modules_collection.get_member(member.target_path)  # type: ignore[union-attr]
                 except KeyError:
-                    _logger.debug(
-                        f"Could not expand wildcard import {member.name} in {obj.path}: "
-                        f"{cast(Alias, member).target_path} not found in modules collection",
+                    logger.debug(
+                        "Could not expand wildcard import %s in %s: %s not found in modules collection",
+                        member.name,
+                        obj.path,
+                        cast(Alias, member).target_path,
                     )
                     continue
 
@@ -366,7 +359,7 @@ class GriffeLoader:
                     try:
                         self.expand_wildcards(target, external=external, seen=seen)
                     except (AliasResolutionError, CyclicAliasError) as error:
-                        _logger.debug(f"Could not expand wildcard import {member.name} in {obj.path}: {error}")
+                        logger.debug("Could not expand wildcard import %s in %s: %s", member.name, obj.path, error)
                         continue
 
                 # Collect every imported object.
@@ -425,6 +418,7 @@ class GriffeLoader:
 
                 # Everything went right (supposedly), we add the alias as a member of the current object.
                 obj.set_member(new_member.name, alias)
+                self.extensions.call("on_wildcard_expansion", alias=alias, loader=self)
 
     def resolve_module_aliases(
         self,
@@ -439,7 +433,7 @@ class GriffeLoader:
 
         Parameters:
             obj: The object and its members to recurse on.
-            implicit: When false, only try to resolve an alias if it is explicitely exported.
+            implicit: When false, only try to resolve an alias if it is explicitly exported.
             external: When false, don't try to load unspecified modules to resolve aliases.
             seen: Used to avoid infinite recursion.
             load_failures: Set of external packages we failed to load (to prevent retries).
@@ -478,17 +472,16 @@ class GriffeLoader:
                         and package not in self.modules_collection
                     )
                     if load_module:
-                        _logger.debug(f"Failed to resolve alias {member.path} -> {target}")
+                        logger.debug("Failed to resolve alias %s -> %s", member.path, target)
                         try:
                             self.load(package, try_relative_path=False)
                         except (ImportError, LoadingError) as error:
-                            _logger.debug(f"Could not follow alias {member.path}: {error}")
+                            logger.debug("Could not follow alias %s: %s", member.path, error)
                             load_failures.add(package)
-                        # TODO: Immediately try again?
                 except CyclicAliasError as error:
-                    _logger.debug(str(error))
+                    logger.debug(str(error))
                 else:
-                    _logger.debug(f"Alias {member.path} was resolved to {member.final_target.path}")  # type: ignore[union-attr]
+                    logger.debug("Alias %s was resolved to %s", member.path, member.final_target.path)  # type: ignore[union-attr]
                     resolved.add(member.path)
 
             # Recurse into unseen modules and classes.
@@ -559,7 +552,7 @@ class GriffeLoader:
         submodules: bool = True,
         parent: Module | None = None,
     ) -> Module:
-        _logger.debug(f"Loading path {module_path}")
+        logger.debug("Loading path %s", module_path)
         if isinstance(module_path, list):
             module = self._create_module(module_name, module_path)
         elif self.force_inspection:
@@ -581,7 +574,7 @@ class GriffeLoader:
     def _load_submodule(self, module: Module, subparts: tuple[str, ...], subpath: Path) -> None:
         for subpart in subparts:
             if "." in subpart:
-                _logger.debug(f"Skip {subpath}, dots in filenames are not supported")
+                logger.debug("Skip %s, dots in filenames are not supported", subpath)
                 return
         try:
             parent_module = self._get_or_create_parent_module(module, subparts, subpath)
@@ -604,8 +597,8 @@ class GriffeLoader:
             # but that's because in that case Python acts like the whole tree is a regular package.
             # It works when the namespace package appears in only one search path (`sys.path`),
             # but will fail if it appears in multiple search paths: Python will only find the first occurrence.
-            # It's better to not falsely suuport this, and to warn users.
-            _logger.debug(f"{error}. Missing __init__ module?")
+            # It's better to not falsely support this, and to warn users.
+            logger.debug("%s. Missing __init__ module?", error)
             return
         submodule_name = subparts[-1]
         try:
@@ -616,15 +609,16 @@ class GriffeLoader:
                 parent=parent_module,
             )
         except LoadingError as error:
-            _logger.debug(str(error))
+            logger.debug(str(error))
         else:
             if submodule_name in parent_module.members:
                 member = parent_module.members[submodule_name]
                 if member.is_alias or not member.is_module:
-                    _logger.debug(
-                        f"Submodule '{submodule.path}' is shadowing the member at the same path. "
+                    logger.debug(
+                        "Submodule '%s' is shadowing the member at the same path. "
                         "We recommend renaming the member or the submodule (for example prefixing it with `_`), "
                         "see https://mkdocstrings.github.io/griffe/best_practices/#avoid-member-submodule-name-shadowing.",
+                        submodule.path,
                     )
             parent_module.set_member(submodule_name, submodule)
 
@@ -736,8 +730,6 @@ def load(
     force_inspection: bool = False,
     store_source: bool = True,
     find_stubs_package: bool = False,
-    # YORE: Bump 1: Remove line.
-    module: str | Path | None = None,
     resolve_aliases: bool = False,
     resolve_external: bool | None = None,
     resolve_implicit: bool = False,
@@ -796,12 +788,11 @@ def load(
         find_stubs_package: Whether to search for stubs-only package.
             If both the package and its stubs are found, they'll be merged together.
             If only the stubs are found, they'll be used as the package itself.
-        module: Deprecated. Use `objspec` positional-only parameter instead.
         resolve_aliases: Whether to resolve aliases.
         resolve_external: Whether to try to load unspecified modules to resolve aliases.
             Default value (`None`) means to load external modules only if they are the private sibling
             or the origin module (for example when `ast` imports from `_ast`).
-        resolve_implicit: When false, only try to resolve an alias if it is explicitely exported.
+        resolve_implicit: When false, only try to resolve an alias if it is explicitly exported.
 
     Returns:
         A Griffe object.
@@ -822,8 +813,6 @@ def load(
         submodules=submodules,
         try_relative_path=try_relative_path,
         find_stubs_package=find_stubs_package,
-        # YORE: Bump 1: Remove line.
-        module=module,
     )
     if resolve_aliases:
         loader.resolve_aliases(implicit=resolve_implicit, external=resolve_external)
@@ -846,8 +835,6 @@ def load_git(
     allow_inspection: bool = True,
     force_inspection: bool = False,
     find_stubs_package: bool = False,
-    # YORE: Bump 1: Remove line.
-    module: str | Path | None = None,
     resolve_aliases: bool = False,
     resolve_external: bool | None = None,
     resolve_implicit: bool = False,
@@ -884,12 +871,11 @@ def load_git(
         find_stubs_package: Whether to search for stubs-only package.
             If both the package and its stubs are found, they'll be merged together.
             If only the stubs are found, they'll be used as the package itself.
-        module: Deprecated. Use `objspec` positional-only parameter instead.
         resolve_aliases: Whether to resolve aliases.
         resolve_external: Whether to try to load unspecified modules to resolve aliases.
             Default value (`None`) means to load external modules only if they are the private sibling
             or the origin module (for example when `ast` imports from `_ast`).
-        resolve_implicit: When false, only try to resolve an alias if it is explicitely exported.
+        resolve_implicit: When false, only try to resolve an alias if it is explicitly exported.
 
     Returns:
         A Griffe object.
@@ -899,10 +885,6 @@ def load_git(
         if isinstance(objspec, Path):
             objspec = worktree / objspec
 
-        # YORE: Bump 1: Remove block.
-        if isinstance(module, Path):
-            module = worktree / module
-
         return load(
             objspec,
             submodules=submodules,
@@ -916,9 +898,49 @@ def load_git(
             allow_inspection=allow_inspection,
             force_inspection=force_inspection,
             find_stubs_package=find_stubs_package,
-            # YORE: Bump 1: Remove line.
-            module=module,
             resolve_aliases=resolve_aliases,
             resolve_external=resolve_external,
             resolve_implicit=resolve_implicit,
         )
+
+
+def load_pypi(
+    package: str,  # noqa: ARG001
+    distribution: str,  # noqa: ARG001
+    version_spec: str,  # noqa: ARG001
+    *,
+    submodules: bool = True,  # noqa: ARG001
+    extensions: Extensions | None = None,  # noqa: ARG001
+    search_paths: Sequence[str | Path] | None = None,  # noqa: ARG001
+    docstring_parser: Parser | None = None,  # noqa: ARG001
+    docstring_options: dict[str, Any] | None = None,  # noqa: ARG001
+    lines_collection: LinesCollection | None = None,  # noqa: ARG001
+    modules_collection: ModulesCollection | None = None,  # noqa: ARG001
+    allow_inspection: bool = True,  # noqa: ARG001
+    force_inspection: bool = False,  # noqa: ARG001
+    find_stubs_package: bool = False,  # noqa: ARG001
+) -> Object | Alias:
+    """Load and return a module from a specific package version downloaded using pip.
+
+    [:octicons-heart-fill-24:{ .pulse } Sponsors only](../../insiders/index.md){ .insiders } &mdash;
+    [:octicons-tag-24: Insiders 1.1.0](../../insiders/changelog.md#1.1.0).
+
+    Parameters:
+        package: The package import name.
+        distribution: The distribution name.
+        version_spec: The version specifier to use when installing with pip.
+        submodules: Whether to recurse on the submodules.
+            This parameter only makes sense when loading a package (top-level module).
+        extensions: The extensions to use.
+        search_paths: The paths to search into (relative to the repository root).
+        docstring_parser: The docstring parser to use. By default, no parsing is done.
+        docstring_options: Additional docstring parsing options.
+        lines_collection: A collection of source code lines.
+        modules_collection: A collection of modules.
+        allow_inspection: Whether to allow inspecting modules when visiting them is not possible.
+        force_inspection: Whether to force using dynamic analysis when loading data.
+        find_stubs_package: Whether to search for stubs-only package.
+            If both the package and its stubs are found, they'll be merged together.
+            If only the stubs are found, they'll be used as the package itself.
+    """
+    raise ValueError("Not available in non-Insiders versions of Griffe")
